<?php

namespace App\Http\Controllers;

use Osiset\BasicShopifyAPI\BasicShopifyAPI;
use Osiset\BasicShopifyAPI\Options;
use Osiset\BasicShopifyAPI\Session;
use Illuminate\Http\Request;
use Log;

class OrderController extends Controller
{
    public $shopifyApi;

    public function __construct()
    {
        // Create options for the Shopify API
        $options = new Options();
        $options->setVersion('2020-01');
        // Create the client and session
        $this->shopifyApi = new BasicShopifyAPI($options);
        $this->shopifyApi->setSession(new Session(env('SHOPIFY_DOMAIN', true), env('SHOPIFY_API_PASSWORD', true)));
        $this->updateOrderTag();
    }

    public function updateOrderTag()
    {
        die('test');
        $webhookData = '{
            "id": 2162814615609,
            "email": "",
            "closed_at": null,
            "created_at": "2020-07-06T04:55:27-04:00",
            "updated_at": "2020-07-06T04:55:32-04:00",
            "number": 212,
            "note": "location5",
            "total_price": "33.60",
            "subtotal_price": "30.00",
            "total_weight": 0,
            "total_tax": "3.60",
            "taxes_included": false,
            "currency": "CAD",
            "financial_status": "paid",
            "confirmed": true,
            "total_discounts": "0.00",
            "total_line_items_price": "30.00",
            "cart_token": null,
            "buyer_accepts_marketing": false,
            "name": "#1212",
            "order_number": 1212,
            "processing_method": "manual",
            "checkout_id": null,
            "source_name": "shopify_draft_order",
            "fulfillment_status": null,
            "tags": "location5",
            "line_items": [
              {
                "id": 4698605944889,
                "variant_id": 31811114500153,
                "title": "p80w test",
                "quantity": 1,
                "sku": "",
                "variant_title": null,
                "vendor": "p80w-devstore-3",
                "fulfillment_service": "manual",
                "product_id": 4686469464121,
                "requires_shipping": true,
                "taxable": true,
                "gift_card": false,
                "name": "p80w test",
                "variant_inventory_management": "shopify",
                "properties": [
                    {
                        "name": "Engraving",
                        "value": "Happy Birthday Mom!"
                    }
                  
                ],
                "product_exists": true,
                "fulfillable_quantity": 1,
                "grams": 0,
                "price": "10.00",
                "total_discount": "0.00",
                "fulfillment_status": null
              },
              {
                "id": 4698605977657,
                "variant_id": 31812045668409,
                "title": "p80w test2",
                "quantity": 1,
                "sku": "",
                "variant_title": null,
                "vendor": "p80w-devstore-3",
                "fulfillment_service": "manual",
                "product_id": 4686752776249,
                "requires_shipping": true,
                "taxable": true,
                "gift_card": false,
                "name": "p80w test2",
                "variant_inventory_management": "shopify",
                "properties": [
                    {
                        "name": "Engraving",
                        "value": "Happy Birthday Mom!"
                    }
                  
                ],
                "product_exists": true,
                "fulfillable_quantity": 1,
                "grams": 0,
                "price": "20.00",
                "total_discount": "0.00",
                "fulfillment_status": null
              }
            ]
          }';

        $orderData = json_decode($webhookData);

        $orderId = $orderData->id;
        $orderTag = $orderData->tags;
        $lineItems = $orderData->line_items;

        foreach ($lineItems as $lineItem) {
            $properties = $lineItem->properties;
            if (!empty($properties)) {
                $engraved = false;
                foreach ($properties as $property) {
                    $name = $property->name;
                    $value = $property->value;

                    if ($name == 'Engraving' && $value != '') {
                        $engraved = true;
                    } else {
                        continue;
                    }
                }
            }
        }

        if ($engraved) {
            // update order tag

            $shopifyRequest = [
                "order" => [
                    "id" => $orderId,
                    "tags" => $orderTag.",engraved"
                ]
            ];

            $data = $this->shopifyApi->rest('PUT', '/admin/orders/'.$orderId.'.json', $shopifyRequest);
            if (!isset($data['body']->container['order']) || empty($data['body']->container['order'])) {
                Log::info('Error while fetching the order');
                Log::info(json_encode($data['errors']));
                die;
            } else {
                $updatedTag = $data['body']->container['order']['tags'];
                Log::info('Succesfully updated the order - '.$orderId. "with tags - ".$updatedTag);
            }
        } else {
            // no need to update tag
            Log::info('No need to update tag for the order -'.$orderId. " (Condition failed)");
        }
    }
}
